<?php
/**
 * crpTag
 *
 * @copyright (c) 2008-2009 Daniele Conca
 * @link http://code.zikula.org/crptag Support and documentation
 * @author Daniele Conca <conca.daniele@gmail.com>
 * @license GNU/GPL - v.2.1
 * @package crpTag
 */

/**
 * initialise block
 *
 */
function crpTag_moduletagsblock_init()
{
	// Security
	pnSecAddSchema('Tagsmoduleblock::', 'Block title::');
}

/**
 * get information on block
 *
 */
function crpTag_moduletagsblock_info()
{
	return array (
		'text_type' => 'crpTags module',
		'module' => 'crpTag',
		'text_type_long' => 'Collection of tags for a module',
		'allow_multiple' => true,
		'form_content' => false,
		'form_refresh' => false,
		'show_preview' => true
	);
}

/**
 * display block
 *
 * @param        array       $blockinfo     a blockinfo structure
 * @return       output      the rendered bock
 */
function crpTag_moduletagsblock_display($blockinfo)
{
	// security check
	if (!SecurityUtil :: checkPermission('Tagsmoduleblock::', "$blockinfo[title]::", ACCESS_READ))
		return;

	if (!pnModAvailable('crpTag'))
		return;

	// get the current language
	$currentlang = pnUserGetLang();

	// Break out options from our content field
	$vars = pnBlockVarsFromContent($blockinfo['content']);
	// get all module vars for later use
	$modvars = pnModGetVar('crpVideo');

	$apiargs['startnum'] = 1;
	$apiargs['numitems'] = $modvars['tag_itemsperpage'];
	$apiargs['extended'] = true;
	$apiargs['groupbyname'] = true;
	$apiargs['tagmodule'] = $vars['moduletags'];
	$apiargs['interval'] = $vars['interval'];

	// call the api
	$items = pnModAPIFunc('crpTag', 'user', 'gettags', $apiargs);

	$moduleId = pnModGetIDFromName($vars['moduletags']);
	$moduleInfo = pnModGetInfo($moduleId);

	// create the output object
	$pnRender = pnRender :: getInstance('crpTag', false);

	$pnRender->assign('tags', $items);
	$pnRender->assign('smodule', $vars['moduletags']);
	$pnRender->assign('modname', $moduleInfo['displayname']);
	$pnRender->assign('showcounter', $vars['showcounter']);
	$pnRender->assign('interval', $vars['interval']);
	$pnRender->assign($modvars);

	$blockinfo['content'] = $pnRender->fetch('blocks/crptag_block_moduletags_cloud.htm');

	return pnBlockThemeBlock($blockinfo);
}

/**
 * modify block settings
 *
 * @param        array       $blockinfo     a blockinfo structure
 * @return       output      the bock form
 */
function crpTag_moduletagsblock_modify($blockinfo)
{
	// Break out options from our content field
	$vars = pnBlockVarsFromContent($blockinfo['content']);

	$modulesArray = array_keys(pnModAPIFunc('Modules','admin','gethookedmodules',array('hookmodname' => 'crpTag')));

	// Create output object
	$pnRender = pnRender :: getInstance('crpTag', false);

	// assign the block vars
	$pnRender->assign($vars);
	$pnRender->assign('modulesArray', $modulesArray);

	// Return the output that has been generated by this function
	return $pnRender->fetch('blocks/crptag_block_moduletags_cloud_modify.htm');
}

/**
 * update block settings
 *
 * @param        array       $blockinfo     a blockinfo structure
 * @return       $blockinfo  the modified blockinfo structure
 */
function  crpTag_moduletagsblock_update($blockinfo)
{
	// Get current content
	$vars = pnBlockVarsFromContent($blockinfo['content']);

	// alter the corresponding variable
	$vars['moduletags'] = FormUtil :: getPassedValue('moduletags', null);
	$vars['showcounter'] = FormUtil :: getPassedValue('showcounter', null);
	$vars['interval'] = FormUtil :: getPassedValue('interval', null);

	// write back the new contents
	$blockinfo['content'] = pnBlockVarsToContent($vars);

	// clear the block cache
	$pnRender = pnRender :: getInstance('crpTag');
	$pnRender->clear_cache('blocks/crptag_block_moduletags_cloud.htm');

	return $blockinfo;
}
?>